@@ -21,7 +21,6 @@ from py4j.java_gateway import JavaObject
 from ai.h2o.sparkling.Initializer import Initializer
 from ai.h2o.sparkling.ml.models.H2OMOJOSettings import H2OMOJOSettings
 from ai.h2o.sparkling.ml.params.H2OTypeConverters import H2OTypeConverters
-from ai.h2o.sparkling.H2ODataFrameConverters import H2ODataFrameConverters
 from ai.h2o.sparkling.ml.params.HasIgnoredColsOnMOJO import HasIgnoredColsOnMOJO
 
 
@@ -80,16 +79,6 @@ class H2ORuleFitMOJOModel(H2OSupervisedMOJOModelParams, HasIgnoredColsOnMOJO):
         return value
 
 
-    def getRemoveDuplicates(self):
-        value = self._java_obj.getRemoveDuplicates()
-        return value
-
-
-    def getLambdaValue(self):
-        value = self._java_obj.getLambdaValue()
-        return H2OTypeConverters.scalaArrayToPythonArray(value)
-
-
     def getDistribution(self):
         value = self._java_obj.getDistribution()
         return value
@@ -103,24 +92,3 @@ class H2ORuleFitMOJOModel(H2OSupervisedMOJOModelParams, HasIgnoredColsOnMOJO):
     def getWeightCol(self):
         value = self._java_obj.getWeightCol()
         return value
-
-
-    def getMaxCategoricalLevels(self):
-        value = self._java_obj.getMaxCategoricalLevels()
-        return value
-
-
-    def getAucType(self):
-        value = self._java_obj.getAucType()
-        return value
-
-    # Outputs
-
-    def getRuleImportance(self):
-        value = self._java_obj.getRuleImportance()
-        return H2ODataFrameConverters.scalaToPythonDataFrame(value)
-
-
-    def getIntercept(self):
-        value = self._java_obj.getIntercept()
-        return H2OTypeConverters.scalaArrayToPythonArray(value)
